@@ -5,7 +5,7 @@ use I18N::LangTags ();
 use I18N::LangTags::Detect ();
 use 5.008;
 
-our $VERSION = '0.00013';
+our $VERSION = '0.00014';
 our $AUTHORITY = 'cpan:DMAKI';
 
 BEGIN {
@@ -24,12 +24,6 @@ has auto => (
     default => 1,
 );
 
-has auto_style => (
-    is => 'ro',
-    isa => 'Str',
-    default => 'maketext'
-);
-
 has auto_localizer => (
     is => 'ro',
     isa => 'Data::Localize::Auto',
@@ -58,7 +52,7 @@ subtype 'Data::Localize::LocalizerListArg'
         ! grep { ! blessed $_ || ! $_->does('Data::Localize::Localizer') } @$_;
     }
     => message {
-        'localizers must be a list of Data::Localize::Localizer implementors'
+        'localizers must be a list of Data::Localize::Localizer implementers'
     }
 ;
 coerce 'Data::Localize::LocalizerListArg'
@@ -118,7 +112,7 @@ sub _build__languages {
 sub _build_auto_localizer {
     my $self = shift;
     require Data::Localize::Auto;
-    Data::Localize::Auto->new( style => $self->auto_style );
+    Data::Localize::Auto->new();
 }
 
 sub set_languages {
@@ -195,25 +189,35 @@ sub localize {
     my ($self, $key, @args) = @_;
 
     foreach my $lang ($self->languages) {
-        print STDERR "[Data::Localize]: localize - looking up $lang\n" if DEBUG;
+        if (DEBUG()) {
+            print STDERR "[Data::Localize]: localize - looking up $lang\n";
+        }
         foreach my $localizer (@{$self->get_localizer_from_lang($lang) || []}) {
             my $out = $localizer->localize_for(
                 lang => $lang,
                 id => $key,
                 args => \@args
             );
-            return $out if $out;
+
+            if ($out) {
+                if (DEBUG()) {
+                    print STDERR "[Data::Localize]: got localization: $out\n";
+                }
+                return $out;
+            }
         }
     }
 
-    print STDERR "[Data::Localize]: localize - nothing found in registered languages\n" if DEBUG;
+    if (DEBUG()) {
+        print STDERR "[Data::Localize]: localize - nothing found in registered languages\n";
+    }
 
     # if we got here, we missed on all languages.
     # one last shot. try the '*' slot
     foreach my $localizer (@{$self->get_localizer_from_lang('*') || []}) {
         foreach my $lang ($self->languages) {
             if (DEBUG()) {
-                print STDERR "[Data::Localize]: localize - trying $lang for '*' with localizer $localizer\n" if DEBUG;
+                print STDERR "[Data::Localize]: localize - trying $lang for '*' with localizer $localizer\n";
             }
             my $out = $localizer->localize_for(
                 lang => $lang,
@@ -221,7 +225,10 @@ sub localize {
                 args => \@args
             );
             if ($out) {
-                print STDERR "[Data::Localize]: localize - found for $lang, adding to map\n" if DEBUG;
+                if (DEBUG()) {
+                    print STDERR "[Data::Localize]: localize - found for $lang, adding to map\n";
+                }
+
                 # oh, found one? set it in the localizer map so we don't have
                 # to look it up again
                 $self->add_localizer_map($lang, $localizer);
@@ -259,6 +266,13 @@ sub add_localizer {
         $localizer = $klass->new(%args);
     }
 
+    if (! $localizer || ! $localizer->isa( 'Data::Localize::Localizer' ) ) {
+        Carp::confess("Bad localizer: '" . ( defined $localizer ? $localizer : '(null)' ) . "'");
+    }
+
+    if (DEBUG()) {
+        print STDERR "[Data::Localize]: add_localizer $localizer\n";
+    }
     $localizer->register($self);
     push @{ $self->_localizers }, $localizer;
 }
@@ -326,12 +340,33 @@ Data::Localize is an object oriented approach to localization, aimed to
 be an alternate choice for Locale::Maketext, Locale::Maketext::Lexicon, and
 Locale::Maketext::Simple.
 
+=head1 RATIONALE
+
+Functionality-wise, Locale::Maketext does what it advertises to do.
+Here's a few reasons why you might or might not choose Data::Localize
+over Locale::Maketext-based localizers:
+
+=head2 Object-Oriented
+
+Data::Localize is completely object-oriented. YMMV.
+
+=head2 Faster
+
+On my benchmarks, Data::Localize is consistently faster than Locale::Maketext
+by 50~80%
+
+=head2 Scalable For Large Amount Of Lexicons
+
+Whereas Locale::Maketext generally stores the lexicons in memory,
+Data::Localize allows you to store this data in alternate storage.
+By default Data::Localize comes with a BerkeleyDB backend.
+
 =head1 BASIC WORKING 
 
 =head2 STRUCTURE
 
 Data::Localize is a wrapper around various Data::Localize::Localizer 
-implementors (localizers). So if you don't specify any localizers, 
+implementers (localizers). So if you don't specify any localizers, 
 Data::Localize will do... nothing (unless you specify C<auto>).
 
 Localizers are the objects that do the actual localization. Localizers must
@@ -352,7 +387,7 @@ use it as the actual lexicon, if no other applicable lexicons exists.
 
 Locale::Maketext attaches this to the lexicon hash itself, but Data::Localizer
 differs in that it attaches to the Data::Localizer object itself, so you
-don't have to place _AUTO everwhere.
+don't have to place _AUTO everywhere.
 
     # here, we're deliberately not setting any localizers
     my $loc = Data::Localize->new(auto => 1);
@@ -388,7 +423,7 @@ in the current scope
 
     use utf8;
 
-    $loc->loclize( $key, "some-utf8-key-here" );
+    $loc->localize( $key, "some-utf8-key-here" );
 
 =back
 
@@ -399,7 +434,7 @@ with thousands and thousands of long messages, this might not be the ideal
 solution. In such cases, you can change where the lexicons get stored
 
     my $loc = Data::Localize->new();
-    $loc->add_namespace(
+    $loc->add_localizer(
         class         => 'Gettext',
         path          => '/path/to/data/*.po'
         storage_class => 'BerkeleyDB',
@@ -482,14 +517,12 @@ current language set to the result of detect_languages().
 
 =head2 languages
 
-Getht the current list of languages
+Gets the current list of languages
 
 =head2 add_fallback_languages
 
 =head2 fallback_languages
 
-XXX - Consider if fallback_languages can be removed
-
 =head2 count_localizers()
 
 Return the number of localizers available
@@ -502,10 +535,24 @@ Get appropriate localizer for language $lang
 
 Filter localizers
 
+=head1 PERFORMANCE
+
+Benchmark run with Mac OS X (10.5.8) perl 5.8.9 (MacPorts)
+
+  Running benchmarks with
+    Locale::Maketext: 1.13
+    Data::Localize:   0.00013_02
+  
+                       Rate   L::M D::L(Namespace) D::L(Gettext) D::L(Gettext+BDB)
+  L::M              11321/s     --            -34%          -44%              -45%
+  D::L(Namespace)   17241/s    52%              --          -15%              -16%
+  D::L(Gettext)     20270/s    79%             18%            --               -1%
+  D::L(Gettext+BDB) 20408/s    80%             18%            1%                --
+
+  
 =head1 TODO
 
 Gettext style localization files -- Make it possible to decode them
-Check performance -- see benchmark/benchmark.pl
 
 =head1 CONTRIBUTORS
 
@@ -542,4 +589,4 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 =back
 
-=cut
\ No newline at end of file
+=cut
