@@ -5,7 +5,7 @@ use Module::Pluggable::Object;
 use Encode ();
 use Data::Localize::Util qw(_alias_and_deprecate);
 
-with 'Data::Localize::Localizer';
+extends 'Data::Localize::Localizer';
 
 has _namespaces => (
     is => 'rw',
@@ -26,6 +26,25 @@ has _failed_classes => (
     default => sub { +{} }
 );
 
+override register => sub {
+    my ($self, $loc) = @_;
+    super();
+
+    my $finder = Module::Pluggable::Object->new(
+        'require' => 1,
+        search_path => [ $self->namespaces ]
+    );
+
+    # find the languages that we currently support
+    my $re = join('|', $self->namespaces);
+    foreach my $plugin ($finder->plugins) {
+        $plugin =~ s/^(?:$re):://;
+        $plugin =~ s/::/_/g;
+        $loc->add_localizer_map($plugin, $self);
+    }   
+    $loc->add_localizer_map('*', $self);
+};
+
 _alias_and_deprecate lexicon_get => 'get_lexicon';
 
 __PACKAGE__->meta->make_immutable;
@@ -42,23 +61,6 @@ sub namespaces {
     return @{ $self->_namespaces };
 }
 
-sub register {
-    my ($self, $loc) = @_;
-    my $finder = Module::Pluggable::Object->new(
-        'require' => 1,
-        search_path => [ $self->namespaces ]
-    );
-
-    # find the languages that we currently support
-    my $re = join('|', $self->namespaces);
-    foreach my $plugin ($finder->plugins) {
-        $plugin =~ s/^(?:$re):://;
-        $plugin =~ s/::/_/g;
-        $loc->add_localizer_map($plugin, $self);
-    }   
-    $loc->add_localizer_map('*', $self);
-}
-
 sub get_lexicon {
     my ($self, $lang, $id) = @_;
 
@@ -152,7 +154,7 @@ Data::Localize::Namespace - Acquire Lexicons From Module %Lexicon Hash
    package MyApp::I18N::ja;
    use strict;
    our %Lexicon = (
-      "Hello, %1!" => "%1さん、こんにちは!"
+      "Greeting" => "[_1]さん、こんにちは!"
    );
 
    1;
@@ -160,12 +162,11 @@ Data::Localize::Namespace - Acquire Lexicons From Module %Lexicon Hash
    use Data::Localize;
 
    my $loc = Data::Localize::Namespace->new(
-      style => "gettext",
       namespace => "MyApp::I18N",
    );
    my $out = $loc->localize_for(
       lang => 'ja',
-      id   => 'Hello, %1!',
+      id   => 'Greeting',
       args => [ 'John Doe' ]
    );
 
@@ -187,7 +188,7 @@ they will be looked up.
 
 =head2 register
 
-Registeres this localizer to the Data::Localize object
+Registers this localizer to the Data::Localize object
 
 =head1 AUTHOR
 
@@ -220,4 +221,4 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 =back
 
-=cut
\ No newline at end of file
+=cut
